/*
 * Filesystem path utilities.
 *
 * Copyright (C) 2018 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <string.h>

#include "fspath.h"

void rewrite_path(char *path, const char *prefix)
{
    size_t pathlen = strlen(path),
           prefixlen = strlen(prefix),
           newpathlen = pathlen - prefixlen;
    const char *newpath = path + prefixlen;

    /* Copy the new path (minus the prefix) to the base address. */

    memmove(path, newpath, strlen(newpath));

    /* Overwrite remaining traces of the old path. Since the new path has been
       relocated over the prefix, the remaining traces are as long as the
       prefix. */

    memset(path + newpathlen, 0, prefixlen);
}
